package com.ruoyi.cms.service;

import java.util.List;
import com.ruoyi.cms.domain.CommercialArea;

/**
 * 商圈Service接口
 * 
 * @author Lishundong
 * @date 2024-11-12
 */
public interface ICommercialAreaService 
{
    /**
     * 查询商圈
     * 
     * @param commercialAreaId 商圈主键
     * @return 商圈
     */
    public CommercialArea selectCommercialAreaByCommercialAreaId(Long commercialAreaId);

    /**
     * 查询商圈列表
     * 
     * @param commercialArea 商圈
     * @return 商圈集合
     */
    public List<CommercialArea> selectCommercialAreaList(CommercialArea commercialArea);

    /**
     * 新增商圈
     * 
     * @param commercialArea 商圈
     * @return 结果
     */
    public int insertCommercialArea(CommercialArea commercialArea);

    /**
     * 修改商圈
     * 
     * @param commercialArea 商圈
     * @return 结果
     */
    public int updateCommercialArea(CommercialArea commercialArea);

    /**
     * 批量删除商圈
     * 
     * @param commercialAreaIds 需要删除的商圈主键集合
     * @return 结果
     */
    public int deleteCommercialAreaByCommercialAreaIds(Long[] commercialAreaIds);

    List<CommercialArea> appCommercialArea();
}
